==> Dancer-Serializer-CBOR-0.100.tar.gz: Dancer-Serializer-CBOR-0.100/lib/Dancer/Serializer/CBOR.pm <==
package Dancer::Serializer::CBOR;

use strict;
use warnings;
use Carp;
use Dancer::ModuleLoader;
use Dancer::Exception qw(:all);
use base 'Dancer::Serializer::Abstract';

=head1 NAME

Dancer::Serializer::CBOR - serializer for handling CBOR data

=head1 VERSION

Version 0.100

=cut

our $VERSION = '0.100';

=head1 SYNOPSIS

    use Dancer;
    
    set serializer => 'CBOR';
    
    get '/view/user/:id' => sub {
        my $id = params->{'id'};
        return { user => get_id($id) };
    };

=head1 DESCRIPTION

This serializer allows to serialize and deserialize automatically the CBOR (Concise Binary Object Representation) structure.

=head1 METHODS

=cut

# helpers

sub loaded { Dancer::ModuleLoader->load('CBOR::XS') }

sub init {
    my ($self) = @_;
    raise core_serializer => 'CBOR::XS is needed and is not installed'
      unless $self->loaded;
}

=head2 serialize

Serialize a data structure to a concise binary object representation.

=cut

sub serialize {
    my ($self, $entity) = @_;
    CBOR::XS::encode_cbor($entity);
}

=head2 deserialize

Deserialize a concise binary object representation to a data structure.

=cut

sub deserialize {
    my ($self, $content) = @_;
    CBOR::XS::decode_cbor($content);
}

=head2 content_type

Return 'application/cbor'

=cut

sub content_type {'application/cbor'}

=head1 SEE ALSO

=over 4

=item * L<CBOR::XS>

=back

=head1 AUTHOR

David Zurborg, C<< <zurborg@cpan.org> >>

=head1 BUGS

Please report any bugs or feature requests at L<https://github.com/zurborg/libdancer-serializer-cbor-perl/issues/new>.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Dancer::Serializer::CBOR

You can also look for information at:

=over 4

=item * GitHub: Public repository of the module

L<https://github.com/zurborg/libdancer-serializer-cbor-perl>

=back

=head1 COPYRIGHT & LICENSE

Copyright 2014 David Zurborg, all rights reserved.

This program is released under the ISC license.

=cut

1;

==> Dancer-Serializer-CBOR-0.101.tar.gz: Dancer-Serializer-CBOR-0.101/lib/Dancer/Serializer/CBOR.pm <==
use strict;
use warnings;
package Dancer::Serializer::CBOR;
# ABSTRACT: serializer for handling CBOR data

use Carp;
use Dancer::Exception qw(:all);
use CBOR::XS;
use base 'Dancer::Serializer::Abstract';

our $VERSION = '0.101'; # VERSION



sub serialize {
    my ($self, $entity) = @_;
    CBOR::XS::encode_cbor($entity);
}


sub deserialize {
    my ($self, $content) = @_;
    CBOR::XS::decode_cbor($content);
}


sub content_type {'application/cbor'}


1;

__END__

=pod

=head1 NAME

Dancer::Serializer::CBOR - serializer for handling CBOR data

=head1 VERSION

version 0.101

=head1 DESCRIPTION

This serializer allows to serialize and deserialize automatically the CBOR (Concise Binary Object Representation) structure.

=head1 SYNOPSIS

    use Dancer;
    
    set serializer => 'CBOR';
    
    get '/view/user/:id' => sub {
        my $id = params->{'id'};
        return { user => get_id($id) };
    };

=head1 METHODS

=head2 serialize

Serialize a data structure to a concise binary object representation.

=head2 deserialize

Deserialize a concise binary object representation to a data structure.

=head2 content_type

Return 'application/cbor'

=head1 SEE ALSO

=over 4

=item * L<CBOR::XS>

=back

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website
https://github.com/zurborg/libdancer-serializer-cbor-perl/issues

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

David Zurborg <zurborg@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2014 by David Zurborg.

This is free software, licensed under:

  The ISC License

=cut
